@@ -34,9 +34,13 @@ def load_trigram_file(f):
     with open(os.path.join(settings.TRIGRAM_PATH,f),'r') as file_handle:
         for line in file_handle:
             l = line.strip().split("\t")
-            words = []
-            for w in l[0].split(" "):
-                words.append(Orthography.objects.filter(spelling=w)[0])
+            words = l[0].split(" ")
+            ws = Orthography.objects.filter(spelling__in = words)
+            for i in range(len(words)):
+                for s in ws:
+                    if words[i] == s.spelling:
+                        words[i] = s
+                        break
             trgs.append(Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1])))
             if len(trgs) > 100000:
                 Trigram.objects.bulk_create(trgs)
